@@ -3,8 +3,8 @@ from django.shortcuts import get_object_or_404
 from newscenter.models import Article, Newsroom
 
 class NewsroomFeed(Feed):
-    def get_object(self, request, newsroom):
-        return get_object_or_404(Newsroom, slug=newsroom)
+    def get_object(self, request, newsroom, website=''):        
+        return get_object_or_404(Newsroom, slug=newsroom, website_short_name=website)
 
     def title(self, obj):
         return "%s Entries" % obj.name
@@ -16,4 +16,4 @@ class NewsroomFeed(Feed):
         return "Latest entries posted in %s" % obj.name
 
     def items(self, obj):
-        return Article.objects.get_published().filter(newsroom__slug=obj.slug)
+        return Article.objects.get_published().filter(newsroom=obj)
